summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/addressWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/addressWidget.h')
-rw-r--r--kpilot/kpilot/addressWidget.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kpilot/kpilot/addressWidget.h b/kpilot/kpilot/addressWidget.h
index 289b49e3..1fa172b8 100644
--- a/kpilot/kpilot/addressWidget.h
+++ b/kpilot/kpilot/addressWidget.h
@@ -46,13 +46,13 @@ class AddressWidget : public PilotComponent
Q_OBJECT
public:
- AddressWidget(QWidget* parent,const QString& dbpath);
+ AddressWidget(TQWidget* parent,const TQString& dbpath);
~AddressWidget();
// Pilot Component Methods:
virtual void showComponent();
virtual void hideComponent();
- virtual bool preHotSync(QString &);
+ virtual bool preHotSync(TQString &);
virtual void postHotSync();
public slots:
@@ -107,13 +107,13 @@ private:
* Create a sensible "title" for an address, composed
* of first + last name if possible.
*/
- QString createTitle(PilotAddress *,int displayMode);
+ TQString createTitle(PilotAddress *,int displayMode);
/**
* We use a QComboBox fCatList to hold the user-visible names
* of all the categories. The QTextView fAddrInfo is for
* displaying the currently selected address, if any.
* The QListBox fListBox lists all the addresses in the
* currently selected category.
*
* The entire address database is read into memory in the
@@ -123,11 +123,11 @@ private:
*
* The two buttons should speak for themselves.
*/
- QComboBox *fCatList;
- QTextView *fAddrInfo;
+ TQComboBox *fCatList;
+ TQTextView *fAddrInfo;
PilotAddressInfo *fAddressAppInfo;
- QPtrList<PilotAddress> fAddressList;
- QListBox *fListBox;
+ TQPtrList<PilotAddress> fAddressList;
+ TQListBox *fListBox;
QPushButton *fEditButton,*fDeleteButton;
protected:
@@ -107,13 +107,13 @@ private:
/**
- * We use a QComboBox fCatList to hold the user-visible names
- * of all the categories. The QTextView fAddrInfo is for
+ * We use a TQComboBox fCatList to hold the user-visible names
+ * of all the categories. The TQTextView fAddrInfo is for
* displaying the currently selected address, if any.
@@ -107,13 +107,13 @@ private:
* displaying the currently selected address, if any.
- * The QListBox fListBox lists all the addresses in the
+ * The TQListBox fListBox lists all the addresses in the
* currently selected category.
*